@@ -1,16 +1,26 @@
 #' @importFrom data.table fwrite
 #' @importFrom utils write.table
 export_delim <- function(file, x, fwrite = TRUE, sep = "\t", row.names = FALSE,
-                         col.names = TRUE, ...) {
+                         col.names = TRUE, append = FALSE, ...) {
     if (isTRUE(fwrite) & !inherits(file, "connection")) {
-        fwrite(x, file = file, sep = sep, col.name = col.names,
-               row.names = row.names, ...)
+        if (isTRUE(append)) {
+            data.table::fwrite(x, file = file, sep = sep, row.names = row.names, 
+                               col.names = FALSE, append = TRUE, ...)
+        } else {
+            data.table::fwrite(x, file = file, sep = sep, row.names = row.names,
+                               col.names = col.names, append = FALSE, ...)
+        }
     } else {
         if (isTRUE(fwrite) & inherits(file, "connection")) {
             message("data.table::fwrite() does not support writing to connections. Using utils::write.table() instead.")
         }
-        write.table(x, file = file, sep = sep, row.names = row.names,
-                    col.names = col.names, ...)
+        if (isTRUE(append)) {
+            write.table(x, file = file, sep = sep, row.names = row.names,
+                        col.names = FALSE, append = TRUE, ...)
+        } else {
+            write.table(x, file = file, sep = sep, row.names = row.names,
+                        col.names = col.names, append = FALSE, ...)
+        }
     }
 }
 
@@ -25,19 +35,18 @@ export_delim <- function(file, x, fwrite = TRUE, sep = "\t", row.names = FALSE,
 }
 
 #' @export
-.export.rio_csv <- function(file, x, ...) {
-    export_delim(x = x, file = file, sep = ",", dec = ".", ...)
+.export.rio_csv <- function(file, x, sep = ",", dec = ".", ...) {
+    export_delim(x = x, file = file, sep = sep, dec = dec, ...)
 }
 
 #' @export
-.export.rio_csv2 <- function(file, x, ...) {
-    export_delim(x = x, file = file, sep =";", dec = ",", ...)
+.export.rio_csv2 <- function(file, x, sep = ";", dec = ",", ...) {
+    export_delim(x = x, file = file, sep = sep, dec = dec, ...)
 }
 
 #' @export
-.export.rio_csvy <- function(file, x, ...) {
-    requireNamespace("csvy")
-    csvy::write_csvy(file = file, x = x, ...)
+.export.rio_csvy <- function(file, x, sep = ",", dec = ".", yaml = TRUE, ...) {
+    export_delim(x = x, file = file, sep = sep, dec = dec, yaml = TRUE, ...)
 }
 
 #' @export
@@ -96,8 +105,8 @@ export_delim <- function(file, x, fwrite = TRUE, sep = "\t", row.names = FALSE,
         }
     }
     cat(paste0("#", capture.output(write.csv(dict, row.names = FALSE, quote = FALSE))), file = file, sep = "\n")
-    write.table(dat, file = file, append = TRUE, row.names = row.names, sep = sep, quote = quote,
-                col.names = col.names, ...)
+    utils::write.table(dat, file = file, append = TRUE, row.names = row.names, sep = sep, quote = quote,
+                       col.names = col.names, ...)
 }
 
 #' @export
@@ -156,21 +165,28 @@ export_delim <- function(file, x, fwrite = TRUE, sep = "\t", row.names = FALSE,
 #' @export
 .export.rio_sav <- function(file, x, ...) {
     x <- restore_labelled(x)
-    write_sav(data = x, path = file, ...)
+    haven::write_sav(data = x, path = file, ...)
+}
+
+#' @importFrom haven write_sav
+#' @export
+.export.rio_zsav <- function(file, x, compress = TRUE, ...) {
+    x <- restore_labelled(x)
+    haven::write_sav(data = x, path = file, compress = compress, ...)
 }
 
 #' @importFrom haven write_dta
 #' @export
 .export.rio_dta <- function(file, x, ...) {
     x <- restore_labelled(x)
-    write_dta(data = x, path = file, ...)
+    haven::write_dta(data = x, path = file, ...)
 }
 
 #' @importFrom haven write_sas
 #' @export
 .export.rio_sas7bdat <- function(file, x, ...) {
     x <- restore_labelled(x)
-    write_sas(data = x, path = file, ...)
+    haven::write_sas(data = x, path = file, ...)
 }
 
 #' @importFrom haven write_xpt
@@ -183,7 +199,7 @@ export_delim <- function(file, x, fwrite = TRUE, sep = "\t", row.names = FALSE,
 #' @importFrom foreign write.dbf
 #' @export
 .export.rio_dbf <- function(file, x, ...) {
-    write.dbf(dataframe = x, file = file, ...)
+    foreign::write.dbf(dataframe = x, file = file, ...)
 }
 
 #' @export
@@ -195,7 +211,7 @@ export_delim <- function(file, x, fwrite = TRUE, sep = "\t", row.names = FALSE,
 #' @importFrom foreign write.arff
 #' @export
 .export.rio_arff <- function(file, x, ...) {
-    write.arff(x = x, file = file, ...)
+    foreign::write.arff(x = x, file = file, ...)
 }
 
 #' @importFrom openxlsx write.xlsx
@@ -246,6 +262,8 @@ export_delim <- function(file, x, fwrite = TRUE, sep = "\t", row.names = FALSE,
     }
     for (i in seq_along(x)) {
         x[[i]][] <- lapply(x[[i]], as.character)
+        x[[i]][] <- lapply(x[[i]], function(v) gsub('&','&amp;',v))
+        names(x[[i]]) <- gsub('&','&amp;',names(x[[i]]))
         tab <- xml2::xml_add_child(bod, "table")
         # add header row
         invisible(xml2::xml_add_child(tab, xml2::read_xml(paste0(twrap(paste0(twrap(names(x[[i]]), "th"), collapse = ""), "tr"), "\n"))))
@@ -266,6 +284,10 @@ export_delim <- function(file, x, fwrite = TRUE, sep = "\t", row.names = FALSE,
     for (a in seq_along(att)) {
         xml2::xml_attr(xml, names(att)[a]) <- att[[a]]
     }
+    # remove illegal characters
+    row.names(x) <- gsub('&', '&amp;', row.names(x))
+    colnames(x) <- gsub('[ &]', '.', colnames(x))
+    x[] <- lapply(x, function(v) gsub('&', '&amp;', v))
     # add data
     for (i in seq_len(nrow(x))) {
         thisrow <- xml2::xml_add_child(xml, "Observation")
@@ -289,3 +311,15 @@ export_delim <- function(file, x, fwrite = TRUE, sep = "\t", row.names = FALSE,
     requireNamespace("clipr")
     clipr::write_clip(content = x, row.names = row.names, col.names = col.names, sep = sep, ...)
 }
+
+#' @export
+.export.rio_pzfx <- function(file, x, ..., row_names=FALSE) {
+    requireNamespace("pzfx")
+    pzfx::write_pzfx(x=x, path=file, ..., row_names=row_names)
+}
+
+#' @export
+.export.rio_parquet <- function(file, x, ...) {
+    requireNamespace("arrow")
+    arrow::write_parquet(x=x, sink=file, ...)
+}
